import { types, getSnapshot, cast } from 'mobx-state-tree';
import { useState } from 'react';

const useMstImmer = (props, initialState) => {
  const [model] = useState(() => {
    const m = types.model(props).actions(self => ({
      set(updater) {
        updater(self);
        const snapshot = getSnapshot(cast(self));
        setSnapshot(snapshot);
        return snapshot;
      }
    }));
    return m.create(typeof initialState === 'function' ? initialState() : initialState);
  });
  const [snapshot, setSnapshot] = useState(() => getSnapshot(cast(model)));
  return [snapshot, model.set];
};

export { useMstImmer };
//# sourceMappingURL=use-mst-immer.modern.js.map
